#! /bin/bash
# this script generates FIXM bindings and copies the jars into the external repo

# print the script usage
printUsage() {
    echo "USAGE:"
    echo "./build-bindings.sh <path_to_fixm_external> <fixm_version> [svn_user] [svn_pass]"
    echo "  <path_to_fixm_external> Path to local, checked-out copy of the fixm-external repository"
    echo "  <fixm_version> The current version of the FIXM schemas"
    echo "  [svn_user] (Optional) The svn username to use to check in the bindings jars, if necessary"
    echo "  [svn_pass] (Optional) The svn password to use to check in the binding jars, if necessary"
    exit
}

# catch arguments
if [[ "$1" != "" && "$2" != "" ]]; then
    if [[ "$@" == *--usage* ]]; then
	printUsage
    else
	fixmextloc="$1"
	version="$2"
    fi
else
    echo "Please provide necessary arguments."
    printUsage
    exit
fi

# catch options
if [ "$3" != "" ]; then
    svnuser="$3"
fi
if [ "$4" != "" ]; then
    svnpass="$4"
fi


# check that the arguments are valid
if [[ -d $fixmextloc ]]; then
    echo "External FIXM repo exists in expected location."
else
    echo "Unable to find external FIXM repo in provided location: $fixmextloc"
    printUsage
fi

libdir=$fixmextloc/examples/lib

# build the xmlbeans bindings
echo "Building XMLBeans bindings"
mvn clean xmlbeans:xmlbeans package
schemajar=target/fixm-schemas*.jar
echo $schemajar

if [[ `ls $schemajar` != "" ]]; then
    echo "XMLBeans jar exists in expected location -- moving to $libdir"
else
    echo "Unable to find XMLBeans jar in expected location."
    exit
fi

# move the xmlbeans jar into the external FIXM repo
xmlbeansjar=fixm-bindings-xmlbeans-$version.jar
mv $schemajar $libdir/$xmlbeansjar

# build the jaxb bindings
echo "Building JAXB bindings"
mvn clean jaxb2:generate package

if [[ `ls $schemajar` != "" ]]; then
    echo "JAXB jar exists in expected location -- moving to $libdir"
else
    echo "Unable to find JAXB jar in expected location."
    exit
fi

# move the binding jars into the external FIXM repo
jaxbjar=fixm-bindings-jaxb-$version.jar
mv $schemajar $libdir/$jaxbjar

# check in the binding jars
msg="Committing XMLBeans and JAXB bindings"
if [[ $svnuser != "" && $svnpass != "" ]]; then
    ( cd $libdir; svn update --username $svnuser --password $svnpass; svn commit --non-interactive $xmlbeansjar $jaxbjar -m "$msg" --username $svnuser --password $svnpass )
else
    ( cd $libdir; svn update; svn commit --non-interactive $xmlbeansjar $jaxbjar -m "$msg" )
fi
