#! /bin/bash

# print the script usage
printUsage() {
    echo "USAGE:"
    echo "./run-xref <path_to_fixm_external> <path_to_xref_site> <fixm_loc> <fodd_loc>[svn_user] [svn_pass]"
    echo "  <path_to_fixm_external> Path to local, checked-out copy of the fixm-external repository"
    echo "  <path_to_xref_site> Path to local, checked-out copy of the xref-site project"
    echo "  <fixm_loc> The location of the FIXM schemas (xsd)"
    echo "  <fodd_loc> The location of the FODD export"
    echo "  [svn_user] (Optional) The svn username to use to check in the bindings jars, if necessary"
    echo "  [svn_pass] (Optional) The svn password to use to check in the binding jars, if necessary"
    exit
}

# catch arguments
if [[ "$1" != "" && "$2" != "" && "$3" != "" && "$4" != "" ]]; then
    if [[ "$@" == *--usage* ]]; then
	printUsage
    else
	fixmextloc="$1"
	xrefloc="$2"
	fixmloc="$3"
	foddloc="$4"
    fi
else
    echo "Please provide necessary arguments."
    printUsage
    exit
fi

# catch options
if [ "$5" != "" ]; then
    svnuser="$5"
fi
if [ "$6" != "" ]; then
    svnpass="$6"
fi

# check that the arguments are valid
if [[ -d $fixmextloc ]]; then
    echo "External FIXM repo exists in expected location."
else
    echo "Unable to find external FIXM repo in provided location: $fixmextloc"
    printUsage
fi
if [[ -d $xrefloc ]]; then
    echo "Xref-site exists in expected location."
else
    echo "Unable to find xref-site project in provided location: $xrefloc"
    printUsage
fi
if [[ -f $fixmloc ]]; then
    echo "FIXM schemas exist in expected location."
else
    echo "Unable to find FIXM schemas in provided location: $fixmloc"
    printUsage
fi
if [[ -f $foddloc ]]; then
    echo "FODD export exists in expected location."
else
    echo "Unable to find FODD export in provided location: $foddloc"
    printUsage
fi

# build and check in site
echo "Running xref-site"
echo "cd $xrefloc; mvn clean compile exec:java -Dexec.args=\"$fixmloc $foddloc\""
( cd $xrefloc; mvn clean compile exec:java -Dexec.args="$fixmloc $foddloc" )

# wait for it to run
sleep 10

echo "Committing site to external FIXM repo"
msg="Committing xref-site"
sitedest=$fixmextloc/doc/
if [[ $svnuser != "" && $svnpass != "" ]]; then
    ( cd $sitedest ; svn update --username $svnuser --password $svnpass ; svn delete xref --force )
    mv $xrefloc/site $sitedest/xref
    ( cd $sitedest ; svn add xref ; svn commit xref --non-interactive -m "$msg" --username $svnuser --password $svnpass )
else
    ( cd $sitedest ; svn update ; svn delete xref --force )
    mv $xrefloc/site $sitedest/xref 
    ( cd $sitedest ; svn add xref ; svn commit xref --non-interactive -m "$msg" )
fi
